/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ObservabilityPipelineConfig extends cdktf.TerraformMetaArguments {
    /**
    * The pipeline name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#config ObservabilityPipeline#config}
    */
    readonly config?: ObservabilityPipelineConfigA;
}
export interface ObservabilityPipelineConfigDestinationsDatadogLogs {
    /**
    * The unique ID of the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The inputs for the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigDestinationsDatadogLogsToTerraform(struct?: ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsDatadogLogsToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsDatadogLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsDatadogLogsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsDatadogLogs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsDatadogLogsOutputReference;
}
export interface ObservabilityPipelineConfigDestinations {
    /**
    * datadog_logs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#datadog_logs ObservabilityPipeline#datadog_logs}
    */
    readonly datadogLogs?: ObservabilityPipelineConfigDestinationsDatadogLogs[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigDestinationsToTerraform(struct?: ObservabilityPipelineConfigDestinations | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsToHclTerraform(struct?: ObservabilityPipelineConfigDestinations | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinations | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinations | cdktf.IResolvable | undefined);
    private _datadogLogs;
    get datadogLogs(): ObservabilityPipelineConfigDestinationsDatadogLogsList;
    putDatadogLogs(value: ObservabilityPipelineConfigDestinationsDatadogLogs[] | cdktf.IResolvable): void;
    resetDatadogLogs(): void;
    get datadogLogsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsDatadogLogs[] | undefined;
}
export interface ObservabilityPipelineConfigProcessorsAddFieldsField {
    /**
    * The field name to add.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The value to assign to the field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigProcessorsAddFieldsFieldToTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsAddFieldsFieldToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsAddFieldsFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsAddFieldsFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsAddFieldsField[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsAddFieldsFieldOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsAddFields {
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * field block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: ObservabilityPipelineConfigProcessorsAddFieldsField[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsAddFieldsToTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsAddFieldsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsAddFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _field;
    get field(): ObservabilityPipelineConfigProcessorsAddFieldsFieldList;
    putField(value: ObservabilityPipelineConfigProcessorsAddFieldsField[] | cdktf.IResolvable): void;
    resetField(): void;
    get fieldInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsAddFieldsField[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsAddFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsAddFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsAddFieldsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsFilter {
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs should pass through the filter. Logs that match this query continue to downstream components; others are dropped.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigProcessorsFilterToTerraform(struct?: ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsFilterToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsFilterList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsFilter[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsFilterOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsParseJson {
    /**
    * The field to parse.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field: string;
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigProcessorsParseJsonToTerraform(struct?: ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsParseJsonToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsParseJsonOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    get fieldInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsParseJsonList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsParseJson[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsParseJsonOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsQuotaLimit {
    /**
    * Whether to enforce by 'bytes' or 'events'. Valid values are `bytes`, `events`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#enforce ObservabilityPipeline#enforce}
    */
    readonly enforce: string;
    /**
    * The daily quota limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: number;
}
export declare function observabilityPipelineConfigProcessorsQuotaLimitToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaLimitToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable | undefined);
    private _enforce?;
    get enforce(): string;
    set enforce(value: string);
    get enforceInput(): string | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    get limitInput(): number | undefined;
}
export interface ObservabilityPipelineConfigProcessorsQuotaOverridesField {
    /**
    * The field name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The field value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigProcessorsQuotaOverridesFieldToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaOverridesFieldToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsQuotaOverridesFieldOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsQuotaOverridesLimit {
    /**
    * Whether to enforce by 'bytes' or 'events'. Valid values are `bytes`, `events`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#enforce ObservabilityPipeline#enforce}
    */
    readonly enforce: string;
    /**
    * The daily quota limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: number;
}
export declare function observabilityPipelineConfigProcessorsQuotaOverridesLimitToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaOverridesLimitToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable | undefined);
    private _enforce?;
    get enforce(): string;
    set enforce(value: string);
    get enforceInput(): string | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    get limitInput(): number | undefined;
}
export interface ObservabilityPipelineConfigProcessorsQuotaOverrides {
    /**
    * field block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | cdktf.IResolvable;
    /**
    * limit block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit;
}
export declare function observabilityPipelineConfigProcessorsQuotaOverridesToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaOverridesToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable | undefined);
    private _field;
    get field(): ObservabilityPipelineConfigProcessorsQuotaOverridesFieldList;
    putField(value: ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | cdktf.IResolvable): void;
    resetField(): void;
    get fieldInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | undefined;
    private _limit;
    get limit(): ObservabilityPipelineConfigProcessorsQuotaOverridesLimitOutputReference;
    putLimit(value: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit): void;
    get limitInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsQuotaOverrides[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsQuotaOverridesOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsQuota {
    /**
    * Whether to drop events exceeding the limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#drop_events ObservabilityPipeline#drop_events}
    */
    readonly dropEvents: boolean | cdktf.IResolvable;
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Whether to ignore when partition fields are missing.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#ignore_when_missing_partitions ObservabilityPipeline#ignore_when_missing_partitions}
    */
    readonly ignoreWhenMissingPartitions?: boolean | cdktf.IResolvable;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The name of the quota.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * List of partition fields.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#partition_fields ObservabilityPipeline#partition_fields}
    */
    readonly partitionFields?: string[];
    /**
    * limit block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: ObservabilityPipelineConfigProcessorsQuotaLimit;
    /**
    * overrides block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#overrides ObservabilityPipeline#overrides}
    */
    readonly overrides?: ObservabilityPipelineConfigProcessorsQuotaOverrides[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsQuotaToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable | undefined);
    private _dropEvents?;
    get dropEvents(): boolean | cdktf.IResolvable;
    set dropEvents(value: boolean | cdktf.IResolvable);
    get dropEventsInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _ignoreWhenMissingPartitions?;
    get ignoreWhenMissingPartitions(): boolean | cdktf.IResolvable;
    set ignoreWhenMissingPartitions(value: boolean | cdktf.IResolvable);
    resetIgnoreWhenMissingPartitions(): void;
    get ignoreWhenMissingPartitionsInput(): boolean | cdktf.IResolvable | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _partitionFields?;
    get partitionFields(): string[];
    set partitionFields(value: string[]);
    resetPartitionFields(): void;
    get partitionFieldsInput(): string[] | undefined;
    private _limit;
    get limit(): ObservabilityPipelineConfigProcessorsQuotaLimitOutputReference;
    putLimit(value: ObservabilityPipelineConfigProcessorsQuotaLimit): void;
    get limitInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaLimit | undefined;
    private _overrides;
    get overrides(): ObservabilityPipelineConfigProcessorsQuotaOverridesList;
    putOverrides(value: ObservabilityPipelineConfigProcessorsQuotaOverrides[] | cdktf.IResolvable): void;
    resetOverrides(): void;
    get overridesInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaOverrides[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsQuotaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsQuota[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsQuotaOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsRemoveFields {
    /**
    * List of fields to remove from the events.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#fields ObservabilityPipeline#fields}
    */
    readonly fields: string[];
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigProcessorsRemoveFieldsToTerraform(struct?: ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsRemoveFieldsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsRemoveFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable | undefined);
    private _fields?;
    get fields(): string[];
    set fields(value: string[]);
    get fieldsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsRemoveFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsRemoveFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsRemoveFieldsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsRenameFieldsField {
    /**
    * Destination field name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#destination ObservabilityPipeline#destination}
    */
    readonly destination: string;
    /**
    * Whether to keep the original field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#preserve_source ObservabilityPipeline#preserve_source}
    */
    readonly preserveSource: boolean | cdktf.IResolvable;
    /**
    * Source field to rename.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#source ObservabilityPipeline#source}
    */
    readonly source: string;
}
export declare function observabilityPipelineConfigProcessorsRenameFieldsFieldToTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsRenameFieldsFieldToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable | undefined);
    private _destination?;
    get destination(): string;
    set destination(value: string);
    get destinationInput(): string | undefined;
    private _preserveSource?;
    get preserveSource(): boolean | cdktf.IResolvable;
    set preserveSource(value: boolean | cdktf.IResolvable);
    get preserveSourceInput(): boolean | cdktf.IResolvable | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsRenameFieldsField[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsRenameFieldsFieldOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsRenameFields {
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * he inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * field block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: ObservabilityPipelineConfigProcessorsRenameFieldsField[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsRenameFieldsToTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsRenameFieldsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _field;
    get field(): ObservabilityPipelineConfigProcessorsRenameFieldsFieldList;
    putField(value: ObservabilityPipelineConfigProcessorsRenameFieldsField[] | cdktf.IResolvable): void;
    resetField(): void;
    get fieldInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsRenameFieldsField[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsRenameFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsRenameFieldsOutputReference;
}
export interface ObservabilityPipelineConfigProcessors {
    /**
    * add_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#add_fields ObservabilityPipeline#add_fields}
    */
    readonly addFields?: ObservabilityPipelineConfigProcessorsAddFields[] | cdktf.IResolvable;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#filter ObservabilityPipeline#filter}
    */
    readonly filter?: ObservabilityPipelineConfigProcessorsFilter[] | cdktf.IResolvable;
    /**
    * parse_json block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#parse_json ObservabilityPipeline#parse_json}
    */
    readonly parseJson?: ObservabilityPipelineConfigProcessorsParseJson[] | cdktf.IResolvable;
    /**
    * quota block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#quota ObservabilityPipeline#quota}
    */
    readonly quota?: ObservabilityPipelineConfigProcessorsQuota[] | cdktf.IResolvable;
    /**
    * remove_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#remove_fields ObservabilityPipeline#remove_fields}
    */
    readonly removeFields?: ObservabilityPipelineConfigProcessorsRemoveFields[] | cdktf.IResolvable;
    /**
    * rename_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#rename_fields ObservabilityPipeline#rename_fields}
    */
    readonly renameFields?: ObservabilityPipelineConfigProcessorsRenameFields[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsToTerraform(struct?: ObservabilityPipelineConfigProcessors | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsToHclTerraform(struct?: ObservabilityPipelineConfigProcessors | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessors | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessors | cdktf.IResolvable | undefined);
    private _addFields;
    get addFields(): ObservabilityPipelineConfigProcessorsAddFieldsList;
    putAddFields(value: ObservabilityPipelineConfigProcessorsAddFields[] | cdktf.IResolvable): void;
    resetAddFields(): void;
    get addFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsAddFields[] | undefined;
    private _filter;
    get filter(): ObservabilityPipelineConfigProcessorsFilterList;
    putFilter(value: ObservabilityPipelineConfigProcessorsFilter[] | cdktf.IResolvable): void;
    resetFilter(): void;
    get filterInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsFilter[] | undefined;
    private _parseJson;
    get parseJson(): ObservabilityPipelineConfigProcessorsParseJsonList;
    putParseJson(value: ObservabilityPipelineConfigProcessorsParseJson[] | cdktf.IResolvable): void;
    resetParseJson(): void;
    get parseJsonInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsParseJson[] | undefined;
    private _quota;
    get quota(): ObservabilityPipelineConfigProcessorsQuotaList;
    putQuota(value: ObservabilityPipelineConfigProcessorsQuota[] | cdktf.IResolvable): void;
    resetQuota(): void;
    get quotaInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuota[] | undefined;
    private _removeFields;
    get removeFields(): ObservabilityPipelineConfigProcessorsRemoveFieldsList;
    putRemoveFields(value: ObservabilityPipelineConfigProcessorsRemoveFields[] | cdktf.IResolvable): void;
    resetRemoveFields(): void;
    get removeFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsRemoveFields[] | undefined;
    private _renameFields;
    get renameFields(): ObservabilityPipelineConfigProcessorsRenameFieldsList;
    putRenameFields(value: ObservabilityPipelineConfigProcessorsRenameFields[] | cdktf.IResolvable): void;
    resetRenameFields(): void;
    get renameFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsRenameFields[] | undefined;
}
export interface ObservabilityPipelineConfigSourcesDatadogAgentTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesDatadogAgentTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesDatadogAgentTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesDatadogAgentTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigSourcesDatadogAgentTlsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesDatadogAgentTls[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesDatadogAgentTlsOutputReference;
}
export interface ObservabilityPipelineConfigSourcesDatadogAgent {
    /**
    * The unique ID of the source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesDatadogAgentTls[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigSourcesDatadogAgentToTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesDatadogAgentToHclTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesDatadogAgentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesDatadogAgentTlsList;
    putTls(value: ObservabilityPipelineConfigSourcesDatadogAgentTls[] | cdktf.IResolvable): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesDatadogAgentTls[] | undefined;
}
export declare class ObservabilityPipelineConfigSourcesDatadogAgentList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesDatadogAgent[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesDatadogAgentOutputReference;
}
export interface ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption {
    /**
    * The name of the librdkafka option.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The value of the librdkafka option.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigSourcesKafkaLibrdkafkaOptionToTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaLibrdkafkaOptionToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionOutputReference;
}
export interface ObservabilityPipelineConfigSourcesKafkaSasl {
    /**
    * SASL mechanism to use (e.g., PLAIN, SCRAM-SHA-256, SCRAM-SHA-512). Valid values are `PLAIN`, `SCRAM-SHA-256`, `SCRAM-SHA-512`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#mechanism ObservabilityPipeline#mechanism}
    */
    readonly mechanism: string;
}
export declare function observabilityPipelineConfigSourcesKafkaSaslToTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaSaslToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaSaslOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable | undefined);
    private _mechanism?;
    get mechanism(): string;
    set mechanism(value: string);
    get mechanismInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesKafkaTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesKafkaTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigSourcesKafkaTlsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesKafkaTls[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesKafkaTlsOutputReference;
}
export interface ObservabilityPipelineConfigSourcesKafka {
    /**
    * The Kafka consumer group ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#group_id ObservabilityPipeline#group_id}
    */
    readonly groupId: string;
    /**
    * The unique ID of the source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of Kafka topic names to subscribe to. The source ingests messages from each topic specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#topics ObservabilityPipeline#topics}
    */
    readonly topics: string[];
    /**
    * librdkafka_option block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#librdkafka_option ObservabilityPipeline#librdkafka_option}
    */
    readonly librdkafkaOption?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | cdktf.IResolvable;
    /**
    * sasl block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#sasl ObservabilityPipeline#sasl}
    */
    readonly sasl: ObservabilityPipelineConfigSourcesKafkaSasl;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesKafkaTls[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigSourcesKafkaToTerraform(struct?: ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable | undefined);
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _topics?;
    get topics(): string[];
    set topics(value: string[]);
    get topicsInput(): string[] | undefined;
    private _librdkafkaOption;
    get librdkafkaOption(): ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionList;
    putLibrdkafkaOption(value: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | cdktf.IResolvable): void;
    resetLibrdkafkaOption(): void;
    get librdkafkaOptionInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | undefined;
    private _sasl;
    get sasl(): ObservabilityPipelineConfigSourcesKafkaSaslOutputReference;
    putSasl(value: ObservabilityPipelineConfigSourcesKafkaSasl): void;
    get saslInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafkaSasl | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesKafkaTlsList;
    putTls(value: ObservabilityPipelineConfigSourcesKafkaTls[] | cdktf.IResolvable): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafkaTls[] | undefined;
}
export declare class ObservabilityPipelineConfigSourcesKafkaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesKafka[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesKafkaOutputReference;
}
export interface ObservabilityPipelineConfigSources {
    /**
    * datadog_agent block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#datadog_agent ObservabilityPipeline#datadog_agent}
    */
    readonly datadogAgent?: ObservabilityPipelineConfigSourcesDatadogAgent[] | cdktf.IResolvable;
    /**
    * kafka block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#kafka ObservabilityPipeline#kafka}
    */
    readonly kafka?: ObservabilityPipelineConfigSourcesKafka[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigSourcesToTerraform(struct?: ObservabilityPipelineConfigSources | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesToHclTerraform(struct?: ObservabilityPipelineConfigSources | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSources | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSources | cdktf.IResolvable | undefined);
    private _datadogAgent;
    get datadogAgent(): ObservabilityPipelineConfigSourcesDatadogAgentList;
    putDatadogAgent(value: ObservabilityPipelineConfigSourcesDatadogAgent[] | cdktf.IResolvable): void;
    resetDatadogAgent(): void;
    get datadogAgentInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesDatadogAgent[] | undefined;
    private _kafka;
    get kafka(): ObservabilityPipelineConfigSourcesKafkaList;
    putKafka(value: ObservabilityPipelineConfigSourcesKafka[] | cdktf.IResolvable): void;
    resetKafka(): void;
    get kafkaInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafka[] | undefined;
}
export interface ObservabilityPipelineConfigA {
    /**
    * destinations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#destinations ObservabilityPipeline#destinations}
    */
    readonly destinations?: ObservabilityPipelineConfigDestinations;
    /**
    * processors block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#processors ObservabilityPipeline#processors}
    */
    readonly processors?: ObservabilityPipelineConfigProcessors;
    /**
    * sources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#sources ObservabilityPipeline#sources}
    */
    readonly sources?: ObservabilityPipelineConfigSources;
}
export declare function observabilityPipelineConfigAToTerraform(struct?: ObservabilityPipelineConfigA | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigAToHclTerraform(struct?: ObservabilityPipelineConfigA | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigA | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigA | cdktf.IResolvable | undefined);
    private _destinations;
    get destinations(): ObservabilityPipelineConfigDestinationsOutputReference;
    putDestinations(value: ObservabilityPipelineConfigDestinations): void;
    resetDestinations(): void;
    get destinationsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinations | undefined;
    private _processors;
    get processors(): ObservabilityPipelineConfigProcessorsOutputReference;
    putProcessors(value: ObservabilityPipelineConfigProcessors): void;
    resetProcessors(): void;
    get processorsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessors | undefined;
    private _sources;
    get sources(): ObservabilityPipelineConfigSourcesOutputReference;
    putSources(value: ObservabilityPipelineConfigSources): void;
    resetSources(): void;
    get sourcesInput(): cdktf.IResolvable | ObservabilityPipelineConfigSources | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline datadog_observability_pipeline}
*/
export declare class ObservabilityPipeline extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_observability_pipeline";
    /**
    * Generates CDKTF code for importing a ObservabilityPipeline resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ObservabilityPipeline to import
    * @param importFromId The id of the existing ObservabilityPipeline that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ObservabilityPipeline to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.60.0/docs/resources/observability_pipeline datadog_observability_pipeline} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ObservabilityPipelineConfig
    */
    constructor(scope: Construct, id: string, config: ObservabilityPipelineConfig);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _config;
    get config(): ObservabilityPipelineConfigAOutputReference;
    putConfig(value: ObservabilityPipelineConfigA): void;
    resetConfig(): void;
    get configInput(): cdktf.IResolvable | ObservabilityPipelineConfigA | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
